@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
 #include <math.h>
@@ -25,14 +25,18 @@
 #include <unistd.h>
 #include <getopt.h>
 #include <string.h>
-#include <asm/types.h>
 #include <sys/ioctl.h>
-#include <linux/videodev.h>
+#include "videodev.h"
+
+#include "version.h"
+
+#define DEFAULT_DEVICE	"/dev/radio0"
 
 void help(char *prog)
 {
-	printf("usage: %s [-h] [-o] [-q] [-d <dev>] [-t <tuner>] <freq>|on|off [<volume>]\n", prog);
-	printf("\n");
+	printf("fmtools fm version %s\n\n", FMT_VERSION);
+	printf("usage: %s [-h] [-o] [-q] [-d <dev>] [-t <tuner>] <freq>|on|off [<volume>]\n\n", prog);
+	printf("A small controller for Video for Linux radio devices.\n\n");
 	printf("  -h         display this help\n");
 	printf("  -o         override frequency range limits of card\n");
 	printf("  -q         quiet mode\n");
@@ -84,8 +88,9 @@ int main(int argc, char **argv)
 
 	/* need at least a frequency */
 	if (argc < 2) {
-		printf ("usage: %s [-h] [-o] [-q] [-d <dev>] [-t <tuner>] <freq>|on|off [<volume>]\n", argv[0]);
-		exit (1);
+		printf("usage: %s [-h] [-o] [-q] [-d <dev>] [-t <tuner>] "
+			"<freq>|on|off [<volume>]\n", argv[0]);
+		exit(1);
 	}
 
 	progname = argv[0];	/* used after getopt munges argv[] */
@@ -125,14 +130,24 @@ int main(int argc, char **argv)
 		tunevol = defaultvol;
 
 	if (!dev)
-		dev = strdup("/dev/radio0");	/* use default */
+		dev = DEFAULT_DEVICE;
 
 	fd = open(dev, O_RDONLY); 
 	if (fd < 0) {
-		fprintf(stderr, "Unable to open %s: %s\n", dev, strerror(errno));
+		fprintf(stderr, "Unable to open %s: %s\n", 
+			dev, strerror(errno));
 		exit(1);
 	}
 
+	ret = ioctl(fd, VIDIOCGAUDIO, &va);
+	if (ret < 0) {
+		perror("ioctl VIDIOCGAUDIO");
+		exit(1);
+	}
+
+	/* initialize this so it doesn't pick up random junk data */
+	va.balance = 32768;
+
 	if (!strcmp("off", argv[0])) {		/* mute the radio */
 		va.audio = 0;
 		va.volume = 0;
@@ -144,7 +159,7 @@ int main(int argc, char **argv)
 		}
 		
 		if (!quiet)
-			printf ("Radio muted\n");
+			printf("Radio muted\n");
 		exit(0);
 	}
 
@@ -164,12 +179,6 @@ int main(int argc, char **argv)
 		exit(0);
 	}
 
-	ret = ioctl(fd, VIDIOCGAUDIO, &va);
-	if (ret < 0) {
-		perror("ioctl VIDIOCGAUDIO");
-		exit(1);
-	}
-
 	if (argv[0][0] == '+') {		/* volume up */
 		if ((va.volume + increment) > 65535)
 			va.volume = 65535;	/* catch overflows in __u16 */
@@ -180,13 +189,13 @@ int main(int argc, char **argv)
 			printf("Setting volume to %2.2f%%\n", 
 			      (va.volume / 655.35));
 
-		ret = ioctl (fd, VIDIOCSAUDIO, &va);
+		ret = ioctl(fd, VIDIOCSAUDIO, &va);
 		if (ret < 0) {
 			perror("ioctl VIDIOCSAUDIO");
 			exit(1);
 		}
 
-		exit (0);
+		exit(0);
 	}
 
 	if (argv[0][0] == '-') {		/* volume down */
@@ -199,13 +208,13 @@ int main(int argc, char **argv)
 			printf("Setting volume to %2.2f%%\n", 
 				(va.volume / 655.35));
 
-		ret = ioctl (fd, VIDIOCSAUDIO, &va);
+		ret = ioctl(fd, VIDIOCSAUDIO, &va);
 		if (ret < 0) {
 			perror("ioctl VIDIOCSAUDIO");
 			exit(1);
 		}
 
-		exit (0);
+		exit(0);
 	}		
 
 	/* at this point, we are trying to tune to a frequency */
@@ -228,7 +237,7 @@ int main(int argc, char **argv)
 	else
 		fact = 16000.;
 
-	freq = ceil(atof(argv[0]) * fact);	/* rounding up matters */
+	freq = rint(atof(argv[0]) * fact);	/* rounding to nearest int */
 
 	if ((freq < vt.rangelow) || (freq > vt.rangehigh)) {
 		if (override == 0) {
@@ -243,7 +252,7 @@ int main(int argc, char **argv)
 	ret = ioctl(fd, VIDIOCSFREQ, &freq);
 	if (ret < 0) {
 		perror("ioctl VIDIOCSFREQ");
-		exit (1);
+		exit(1);
 	}
 
 	va.audio = 0;
@@ -258,7 +267,7 @@ int main(int argc, char **argv)
 	}
 
 	if (!quiet) 
-		printf ("Radio tuned to %2.1f MHz at %2.2f%% volume\n", 
+		printf("Radio tuned to %2.2f MHz at %2.2f%% volume\n", 
 			(freq / fact), (tunevol / 655.35));
 
 	return 0;
